@@ -3,7 +3,7 @@ from datetime import datetime
 from os import makedirs, path, walk
 from re import search
 
-from colorifix.colorifix import Color, paint
+from colorifix.colorifix import paint
 from emoji import emojize
 from halo import Halo
 from pymortafix.utils import multisub
@@ -16,6 +16,17 @@ CONFIG = get_config()
 SPINNER = Halo()
 
 
+# --- COLORS
+
+COLORS = CONFIG.get("colors")
+c_action_download = COLORS.get("action-download")
+c_anime_download = COLORS.get("anime-name-download")
+c_episode_download = COLORS.get("episode-download")
+
+
+# --- UTILS
+
+
 def last_episodes_downloaded(folder_name, season):
     tree = list(walk(path.join(CONFIG.get("path"), folder_name, f"Stagione {season}")))
     if not tree:
@@ -32,6 +43,15 @@ def sanitize_name(name):
     return multisub({":": "", " ": "_"}, name)
 
 
+def build_filename(base, title, season, episode):
+    filename = CONFIG.get("format", "<title_>_s<season>e<episode>")
+    filename = filename.replace("<season>", f"{int(season):02d}")
+    filename = filename.replace("<episode>", f"{int(episode):02d}")
+    filename = filename.replace("<title>", title)
+    filename = filename.replace("<title_>", sanitize_name(title))
+    return path.join(base, f"{filename}.mp4")
+
+
 def send_telegram_log(name, season, episode, success=True):
     config = get_config()
     bot_token = config.get("telegram-bot-token")
@@ -51,10 +71,30 @@ def send_telegram_log(name, season, episode, success=True):
 
 
 def download_video(url, name, filename):
-    with YoutubeDL({"outtmpl": filename, "quiet": True, "no_warnings": True}) as ydl:
+    with YoutubeDL(
+        {
+            "outtmpl": filename,
+            "quiet": True,
+            "no_warnings": True,
+            "nocheckcertificate": True,
+        }
+    ) as ydl:
         ydl.download([url])
 
 
+def spinner(func, action, anime, season, episode):
+    func(
+        paint(
+            f"[#{c_action_download}]{action} "
+            f"[#{c_anime_download}]{anime} "
+            f"[#{c_episode_download}]{season}x{episode}"
+        )
+    )
+
+
+# --- DOWNLOADS
+
+
 def download(action):
     anime_list = [list(anime.values()) for anime in CONFIG.get("anime")]
     for name, url, season, folder, mode in anime_list:
@@ -71,32 +111,18 @@ def download(action):
                 basepath = path.join(CONFIG.get("path"), folder, f"Stagione {season}")
                 if not path.exists(basepath):
                     makedirs(basepath)
-                filename = path.join(
-                    basepath, f"{sanitize_name(name)}_s{int(season):02d}e{ep:02d}.mp4"
-                )
-                SPINNER.start(
-                    f"Downloading {paint(name,Color.BLUE)} "
-                    f"{paint(f'{season}x{ep}',Color.MAGENTA)}"
-                )
+                filename = build_filename(basepath, name, season, ep)
+                spinner(SPINNER.start, "Downloading", name, season, ep)
                 try:
                     download_video(episode_link, name, filename)
                 except Exception:
-                    SPINNER.fail(
-                        f"Fail to download {paint(name,Color.BLUE)} "
-                        f"{paint(f'{season}x{ep}',Color.MAGENTA)}"
-                    )
+                    spinner(SPINNER.fail, "Fail to download", name, season, ep)
                     send_telegram_log(name, season, ep, success=False)
                     break
-                SPINNER.succeed(
-                    f"Downloaded {paint(name,Color.BLUE)} "
-                    f"{paint(f'{season}x{ep}',Color.MAGENTA)}"
-                )
+                spinner(SPINNER.succeed, "Downloaded", name, season, ep)
                 send_telegram_log(name, season, ep)
             elif action == "test":
-                SPINNER.info(
-                    f"Found {paint(name, Color.BLUE)} "
-                    + paint(f"{season}x{ep}", Color.MAGENTA)
-                )
+                spinner(SPINNER.info, "Found", name, season, ep)
 
 
 def argparsing():
